Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(59)

Unified Diff: src/codec/SkSwizzler.h

Issue 1287423002: Scanline decoding for bmp (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Scaling for all types of bmps Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/codec/SkSwizzler.h
diff --git a/src/codec/SkSwizzler.h b/src/codec/SkSwizzler.h
index b7132ce6d5b38b68e1a5b9832083108d9669948e..14c453ea48408c32bf4a68d3468a981b7197be02 100644
--- a/src/codec/SkSwizzler.h
+++ b/src/codec/SkSwizzler.h
@@ -188,15 +188,16 @@ private:
* @param dstRow Row in which to write the resulting pixels.
* @param src Row of src data, in format specified by SrcConfig
* @param dstWidth Width in pixels of the destination
* @param deltaSrc if bitsPerPixel % 8 == 0, deltaSrc is bytesPerPixel
* else, deltaSrc is bitsPerPixel
scroggo 2015/08/26 22:40:09 It seems a little weird to me that these two param
msarett 2015/08/27 15:00:27 I agree that it it strange - but I think this is b
scroggo 2015/08/27 20:14:22 Agreed.
* @param ctable Colors (used for kIndex source).
* @param offset The offset before the first pixel to sample.
Is in bytes or bits based on what deltaSrc is in.
*/
typedef ResultAlpha (*RowProc)(void* SK_RESTRICT dstRow,
const uint8_t* SK_RESTRICT src,
- int dstWidth, int deltaSrc, int offset,
+ int dstWidth, int bpp, int deltaSrc, int offset,
const SkPMColor ctable[]);
const RowProc fRowProc;
@@ -188,15 +188,16 @@ private:
* @param src Row of src data, in format specified by SrcConfig
* @param dstWidth Width in pixels of the destination
- * @param deltaSrc if bitsPerPixel % 8 == 0, deltaSrc is bytesPerPixel
- * else, deltaSrc is bitsPerPixel
+ * @param bpp if bitsPerPixel % 8 == 0, deltaSrc is bytesPerPixel
+ * else, deltaSrc is bitsPerPixel
+ * @param deltaSrc bpp * sampleX
scroggo 2015/08/26 22:40:09 It seems a little weird to me that these two param
msarett 2015/08/27 15:00:27 I agree that it it strange - but I think this is b

Powered by Google App Engine
This is Rietveld 408576698